==> cutefish-core_0.4.orig.tar.gz: core-0.4/settings-daemon/translations/es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX" sourcelanguage="de_DE">
<context>
    <name>Battery</name>
    <message>
        <location filename="../battery/battery.cpp" line="268"/>
        <source>%1d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="274"/>
        <source>%1h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="281"/>
        <source>%1m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="290"/>
        <source>%1 until fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="292"/>
        <source>%1 remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="294"/>
        <source>Fully charged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="317"/>
        <source>now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="319"/>
        <source>%1 ago</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UPowerDevice</name>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="71"/>
        <source>%1 Battery</source>
        <comment>%1 is battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="87"/>
        <source>Lithium-ion</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="89"/>
        <source>Lithium Polymer</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="91"/>
        <source>Lithium Iron Phosphate</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="93"/>
        <source>Lead Acid</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="95"/>
        <source>Nickel Cadmium</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="97"/>
        <source>Nickel Metal Hydride</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="99"/>
        <source>Unknown</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutefish-core_0.8.orig.tar.gz: core-0.8/settings-daemon/translations/es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX" sourcelanguage="de_DE">
<context>
    <name>Battery</name>
    <message>
        <location filename="../battery/battery.cpp" line="268"/>
        <source>%1d</source>
        <translation>%1d</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="274"/>
        <source>%1h</source>
        <translation>%1h</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="281"/>
        <source>%1m</source>
        <translation>%1m</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="290"/>
        <source>%1 until fully charged</source>
        <translation>%1 hasta completar la carga</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="292"/>
        <source>%1 remaining</source>
        <translation>%1 restante</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="294"/>
        <source>Fully charged.</source>
        <translation>Completamente cargado(a).</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="317"/>
        <source>now</source>
        <translation>ahora</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="319"/>
        <source>%1 ago</source>
        <translation>%1 atras</translation>
    </message>
</context>
<context>
    <name>UPowerDevice</name>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="71"/>
        <source>%1 Battery</source>
        <comment>%1 is battery technology</comment>
        <translation>%1 de Batería</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="87"/>
        <source>Lithium-ion</source>
        <comment>battery technology</comment>
        <translation>Batería de ion de litio</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="89"/>
        <source>Lithium Polymer</source>
        <comment>battery technology</comment>
        <translation>Polímero de Litio</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="91"/>
        <source>Lithium Iron Phosphate</source>
        <comment>battery technology</comment>
        <translation>Fosfato de hierro y litio</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="93"/>
        <source>Lead Acid</source>
        <comment>battery technology</comment>
        <translation>Plomo ácido</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="95"/>
        <source>Nickel Cadmium</source>
        <comment>battery technology</comment>
        <translation>Nickel cadmio</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="97"/>
        <source>Nickel Metal Hydride</source>
        <comment>battery technology</comment>
        <translation>Hidruro metálico de níquel</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="99"/>
        <source>Unknown</source>
        <comment>battery technology</comment>
        <translation>Desconocido</translation>
    </message>
</context>
</TS>
